Customize the number of cluster in the Seurat object
Arguments
- seu
A
Seuratobject- n_clusters
A scalar, the desired number of clusters
- verbose
Default is
FALSE
Customize the number of cluster in the Seurat object
A Seurat object
A scalar, the desired number of clusters
Default is FALSE