Find the optimal number of cell clusters for Seurat object
Source:R/cluster.R
OptimalNumClusters.RdFind the optimal number of cell clusters using fpc::prediction.strenth
Usage
OptimalNumClusters(seu, reduction = c("pca", "umap"))R/cluster.R
OptimalNumClusters.RdFind the optimal number of cell clusters using fpc::prediction.strenth
OptimalNumClusters(seu, reduction = c("pca", "umap"))